@@ -32,13 +32,12 @@ from __future__ import annotations
 
 import datetime
 import re
-from typing import get_args, Literal, Optional, TYPE_CHECKING, Union
+from typing import Literal, Optional, TYPE_CHECKING, Union
 
 from lxml import html
 
-from compass.core import errors
+import compass.core as ci
 from compass.core.logger import logger
-from compass.core.schemas import member as schema
 from compass.core.settings import Settings
 from compass.core.util import cache_hooks
 from compass.core.util.context_managers import validation_errors_logging
@@ -46,7 +45,7 @@ from compass.core.util.type_coercion import maybe_int
 from compass.core.util.type_coercion import parse_date
 
 if TYPE_CHECKING:
-    from collections.abc import Iterable
+    from collections.abc import Collection
     from collections.abc import Iterator
 
     from compass.core.util.client import Client
@@ -60,11 +59,11 @@ if TYPE_CHECKING:
 # _get_member_profile_tab
 MEMBER_PROFILE_TAB_TYPES = Literal[
     "Personal", "Roles", "Permits", "Training", "Awards", "Emergency", "Comms", "Visibility", "Disclosures"
-]
-TABS = {tab.upper() for tab in get_args(MEMBER_PROFILE_TAB_TYPES)}
+]  # sync with below
+TABS = {"PERSONAL", "ROLES", "PERMITS", "TRAINING", "AWARDS", "EMERGENCY", "COMMS", "VISIBILITY", "DISCLOSURES"}  # sync with above
 
 # get_roles_tab
-ROLE_STATUSES = set(get_args(schema.TYPES_ROLE_STATUS))
+ROLE_STATUSES = {"Cancelled", "Closed", "Full", "Pre provisional", "Provisional"}  # sync with schemas/member.py::TYPES_ROLE_STATUS
 NON_VOLUNTEER_TITLES = {
     # occasional helper roles:
     "group occasional helper",
@@ -108,6 +107,9 @@ NON_VOLUNTEER_TITLES = {
     "bso scout network member",
 }
 
+# _reduce_date_list
+ADJACENT = datetime.timedelta(days=-1)
+
 # get_training_tab
 mogl_modules = {
     "SA": "safety",
@@ -139,17 +141,17 @@ def _get_member_profile_tab(client: Client, membership_number: int, profile_tab:
     if tab_upper in TABS:
         url += f"&Page={tab_upper}&TAB"
     elif tab_upper != "PERSONAL":  # Personal tab has no key so is a special case
-        raise errors.CompassError(f"Specified member profile tab {profile_tab} is invalid. Allowed values are {TABS}")
+        raise ci.CompassError(f"Specified member profile tab {profile_tab} is invalid. Allowed values are {TABS}")
 
     response = client.get(url).content
     tree = html.fromstring(response)
     if tree.forms[0].action == "./ScoutsPortal.aspx?Invalid=AccessCN":
-        raise errors.CompassPermissionError(f"You do not have permission to the details of {membership_number}")
+        raise ci.CompassPermissionError(f"You do not have permission to the details of {membership_number}")
     return tree
 
 
 @cache_hooks.cache_result(key=("personal", 1))
-def get_personal_tab(client: Client, membership_number: int, /) -> schema.MemberDetails:
+def get_personal_tab(client: Client, membership_number: int, /) -> ci.MemberDetails:
     """Returns data from Personal Details tab for a given member.
 
     Args:
@@ -190,7 +192,7 @@ def get_personal_tab(client: Client, membership_number: int, /) -> schema.Member
 
     """
     tree = _get_member_profile_tab(client, membership_number, "Personal")
-    details: dict[str, Union[None, int, str, datetime.date, schema.AddressData, dict[str, str]]] = dict()
+    details: dict[str, Union[None, int, str, datetime.date, ci.AddressData, dict[str, str]]] = dict()
 
     # ### Extractors
     # ## Core:
@@ -240,10 +242,10 @@ def get_personal_tab(client: Client, membership_number: int, /) -> schema.Member
     details = {k: v for k, v in details.items() if v}
 
     with validation_errors_logging(membership_number):
-        return schema.MemberDetails.parse_obj(details)
+        return ci.MemberDetails.parse_obj(details)
 
 
-def _process_address(address: str) -> schema.AddressData:
+def _process_address(address: str) -> ci.AddressData:
     if "UK" in address:
         addr_main, addr_code = address.rsplit(". ", 1)
         postcode, country = addr_code.rsplit(" ", 1)  # Split Postcode & Country
@@ -281,7 +283,7 @@ def get_roles_tab(
     membership_number: int,
     /,
     only_volunteer_roles: bool = True,
-) -> schema.MemberRolesCollection:
+) -> ci.MemberRolesCollection:
     """Returns data from Roles tab for a given member.
 
     Parses the data to a common format, and removes Occasional Helper, PVG,
@@ -327,8 +329,7 @@ def get_roles_tab(
     """
     logger.debug(f"getting roles tab for member number: {membership_number}")
 
-    tree = _get_member_profile_tab(client, membership_number, "Roles")
-    rows = tree.xpath("//tbody/tr")
+    rows = _get_member_profile_tab(client, membership_number, "Roles").xpath("//tbody/tr")
 
     primary_role = None
     roles_dates = []
@@ -342,20 +343,28 @@ def get_roles_tab(
         if any(el.tag == "input" for el in cells[0]) or cells[0].getchildren() == []:
             cells.pop(0)
 
+        role_class = cells[1].text_content().strip()
+        # sanitise primary roles and note primary role status
         role_title, primary_role = _extract_primary_role(cells[0].text_content().strip(), primary_role)
+        # Skip OHs etc as early as possible
+        non_volunteer = "helper" in role_class.lower() or role_title.lower() in NON_VOLUNTEER_TITLES
+        if only_volunteer_roles and non_volunteer:
+            continue
+
+        # process role status & review date string
         role_status, review_date = _extract_review_date(cells[5].text_content().strip())
 
-        role_details = schema.MemberRoleCore(
+        role_details = ci.MemberRoleCore(
             role_number=int(row.get("data-pk")),
             membership_number=membership_number,
             role_title=role_title,
-            role_class=cells[1].text_content().strip(),
+            role_class=role_class,
             # role_type only visible if access to System Admin tab
             role_type=cells[0][0].get("title", None),
             # location_id only visible if role is in hierarchy AND location still exists
             location_id=cells[2][0].get("data-ng_id"),
             location_name=cells[2].text_content().strip(),
-            role_start=parse_date(cells[3].text_content().strip()),  # type: ignore[arg-type]
+            role_start=parse_date(cells[3].text_content().strip()),  # type  ignore[arg-type]
             role_end=parse_date(cells[4].text_content().strip()),
             role_status=role_status,
             review_date=review_date,
@@ -364,12 +373,8 @@ def get_roles_tab(
         # Save role number if role is primary
         if primary_role is True:
             primary_role = role_details.role_number
-        # Remove OHs etc from list
-        if "helper" in role_details.role_class.lower() or role_details.role_title.lower() in NON_VOLUNTEER_TITLES:
-            if only_volunteer_roles is True:
-                continue
         # If role is a full volunteer role, potentially add to date list
-        elif role_status != "Cancelled":
+        if role_status != "Cancelled" and not non_volunteer:
             # If role_end is a falsy value (None), replace with today's date
             roles_dates.append((role_details.role_start, role_details.role_end or datetime.date.today()))
 
@@ -377,7 +382,7 @@ def get_roles_tab(
 
     with validation_errors_logging(membership_number):
         # Calculate days of membership (inclusive), normalise to years.
-        return schema.MemberRolesCollection(
+        return ci.MemberRolesCollection(
             roles=roles_data,
             membership_duration=_membership_duration(roles_dates),
             primary_role=primary_role,
@@ -392,17 +397,17 @@ def _extract_primary_role(role_title: str, primary_role: Union[int, None]) -> tu
     return role_title, primary_role
 
 
-def _extract_review_date(review_status: str) -> tuple[schema.TYPES_ROLE_STATUS, Optional[datetime.date]]:
+def _extract_review_date(review_status: str) -> tuple[ci.TYPES_ROLE_STATUS, Optional[datetime.date]]:
     if review_status.startswith("Full Review Due ") or review_status.startswith("Full Ending "):
         role_status: Literal["Full"] = "Full"
         review_date = parse_date(review_status.removeprefix("Full Review Due ").removeprefix("Full Ending "))
         return role_status, review_date
     if review_status in ROLE_STATUSES:
         return review_status, None  # type: ignore[return-value]  # str -> Literal type narrowing doesn't seem to work?
-    raise errors.CompassError(f"Invalid value for review status '{review_status}'!")
+    raise ci.CompassError(f"Invalid value for review status '{review_status}'!")
 
 
-def _membership_duration(dates: Iterable[tuple[datetime.date, datetime.date]]) -> float:
+def _membership_duration(dates: Collection[tuple[datetime.date, datetime.date]]) -> float:
     """Calculate days of membership (inclusive), normalise to years."""
     if not dates:  # handle empty iterable
         return 0
@@ -410,65 +415,41 @@ def _membership_duration(dates: Iterable[tuple[datetime.date, datetime.date]]) -
     return round(membership_duration_days / 365.2425, 3)  # Leap year except thrice per 400 years.
 
 
-def _reduce_date_list(dates: Iterable[tuple[datetime.date, datetime.date]]) -> Iterator[tuple[datetime.date, datetime.date]]:
+def _reduce_date_list(dates: Collection[tuple[datetime.date, datetime.date]]) -> Iterator[tuple[datetime.date, datetime.date]]:
     """Reduce list of start and end dates to disjoint ranges.
 
-    Iterate through date pairs and get longest consecutive date ranges. For
-    disjoint ranges, call function recursively. Returns all found date pairs.
+    Iterate through date pairs and get longest consecutive date ranges. Returns
+    all found date pairs.
 
     Args:
         dates: list of start, end date pairs
 
     Returns:
-        list of start, end date pairs
+        list of reduced start, end date pairs
 
     """
-    unused_values = set()  # We init the date values with the first
-    # sdl = iter(dates)
-    # earliest_start, latest_end = next(sdl)
-    # for i, (start, end) in enumerate(sdl):
-    sdl = sorted(dates)
-    earliest_start, latest_end = sdl[0]
-    for start, end in sdl[1:]:
-        # If date range completely outwith, set both start and end
-        if start < earliest_start and end > latest_end:
-            earliest_start, latest_end = start, end
-        # If start and latest end overlap, and end is later than latest end, update latest end
-        elif start <= latest_end < end:
-            latest_end = end
-        # If end and earliest start overlap, and start is earlier than earliest start, update earliest start
-        elif end >= earliest_start > start:
-            earliest_start = start
-        # If date range completely within, do nothing
-        elif start >= earliest_start and end <= latest_end:
-            continue
-        # If adjacent
-        elif abs(latest_end - start).days == 1 or abs(earliest_start - end).days == 1:
-            latest_end = max(end, latest_end)
-            earliest_start = min(start, earliest_start)
-        # If none of these (date forms a disjoint set) note as unused
-        else:
-            unused_values.add((start, end))
-    yield earliest_start, latest_end
-    # If there are remaining items not used, pass recursively
-    if unused_values:
-        yield from _reduce_date_list(unused_values)
+    if len(dates) == 0:
+        return []  # bail
 
-    # unused_dates = []
-    # earliest_start, latest_end = sdl[0]
-    # for start, end in sdl[1:]:
-    #     if (start - latest_end).days > 1:
-    #         unused_dates.append((start, end))
-    #         continue
-    #     if end > latest_end:
-    #         latest_end = end
-    # yield earliest_start, latest_end
-    # if unused_dates:
-    #     yield from _reduce_date_list(unused_dates)
+    dates = sorted(dates)  # sort dates oldest first
+    reduced = [dates[0]]  # initialise reduced list with oldest start date
+    for start, end in dates[1:]:
+        range_start, range_end = reduced[-1]
+        # if the start date is more than one day apart from the previous end,
+        # start a new date range. This allow dates to be adjacent, for example
+        # leaving a role on the 31st and starting the next on the 1st
+        if (range_end - start) < ADJACENT:
+            reduced.append((start, end))
+        # if the potential end date is newer than the current end date, modify
+        # the current date range to use the new end date
+        elif end > range_end:
+            reduced[-1] = range_start, end
+
+    return reduced
 
 
 @cache_hooks.cache_result(key=("permits", 1))
-def get_permits_tab(client: Client, membership_number: int, /) -> list[schema.MemberPermit]:
+def get_permits_tab(client: Client, membership_number: int, /) -> list[ci.MemberPermit]:
     """Returns data from Permits tab for a given member.
 
     If a permit has been revoked, the expires value is None and the status is PERM_REV
@@ -496,7 +477,7 @@ def get_permits_tab(client: Client, membership_number: int, /) -> list[schema.Me
             child_nodes = list(row)
             expires = child_nodes[5].text_content()
             permits.append(
-                schema.MemberPermit(
+                ci.MemberPermit(
                     membership_number=membership_number,
                     permit_type=child_nodes[1].text_content(),
                     category=child_nodes[2].text_content(),
@@ -510,7 +491,7 @@ def get_permits_tab(client: Client, membership_number: int, /) -> list[schema.Me
 
 
 @cache_hooks.cache_result(key=("training", 1))
-def get_training_tab(client: Client, membership_number: int, /) -> schema.MemberTrainingTab:
+def get_training_tab(client: Client, membership_number: int, /) -> ci.MemberTrainingTab:
     """Returns data from Training tab for a given member.
 
     Args:
@@ -575,7 +556,7 @@ def get_training_tab(client: Client, membership_number: int, /) -> schema.Member
 
     details = {"roles": training_roles, "plps": training_plps, "mandatory": _compile_ongoing_learning(training_plps, tree)}
     with validation_errors_logging(membership_number):
-        return schema.MemberTrainingTab.parse_obj(details)
+        return ci.MemberTrainingTab.parse_obj(details)
 
 
 def _process_personal_learning_plan(plp: html.HtmlElement) -> tuple[int, list[TYPES_TRAINING_MODULE]]:
@@ -663,7 +644,7 @@ def _compile_ongoing_learning(training_plps: TYPES_TRAINING_PLPS, tree: html.Htm
 
     Returns:
         A map of ogl type -> dates. Data returned here as native types (dicts),
-        see schema.MemberMandatoryTraining for full model.
+        see ci.MemberMandatoryTraining for full model.
 
     """
     # Handle GDPR (Get latest GDPR date)
@@ -691,7 +672,7 @@ def _compile_ongoing_learning(training_plps: TYPES_TRAINING_PLPS, tree: html.Htm
 
 
 @cache_hooks.cache_result(key=("awards", 1))
-def get_awards_tab(client: Client, membership_number: int, /) -> list[schema.MemberAward]:
+def get_awards_tab(client: Client, membership_number: int, /) -> list[ci.MemberAward]:
     """Returns data from Awards tab for a given member.
 
     Args:
@@ -722,18 +703,18 @@ def get_awards_tab(client: Client, membership_number: int, /) -> list[schema.Mem
         for row in rows:
             award_props = row[1][0]  # Properties are stored as yet another sub-table
             awards.append(
-                schema.MemberAward(
+                ci.MemberAward(
                     membership_number=membership_number,
                     type=award_props[0][1].text_content(),
                     location=award_props[1][1].text_content() or None,
-                    date=parse_date(award_props[2][1].text_content() or ""),  # type: ignore[arg-type]
+                    date=parse_date(award_props[2][1].text_content() or ""),  # type  ignore[arg-type]
                 )
             )
     return awards
 
 
 @cache_hooks.cache_result(key=("disclosures", 1))
-def get_disclosures_tab(client: Client, membership_number: int, /) -> list[schema.MemberDisclosure]:
+def get_disclosures_tab(client: Client, membership_number: int, /) -> list[ci.MemberDisclosure]:
     """Returns data from Disclosures tab for a given member.
 
     Args:
@@ -771,7 +752,7 @@ def get_disclosures_tab(client: Client, membership_number: int, /) -> list[schem
             cells = list(row)
 
             disclosures.append(
-                schema.MemberDisclosure(
+                ci.MemberDisclosure(
                     membership_number=membership_number,
                     country=cells[0].text_content() or None,  # Country sometimes missing (Application Withdrawn)
                     provider=cells[1].text_content(),
